"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.hash = hash;
exports.compare = compare;
exports.reset = reset;
exports.update = update;
exports.default = void 0;

var _bcryptjs = _interopRequireDefault(require("bcryptjs"));

var _crypto = _interopRequireDefault(require("crypto"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

var SALT_WORK_FACTOR = 10;

function hash(user) {
  var password = user.password;
  if (!password) throw new Error('No password provided');
  return new Promise(function (resolve, reject) {
    _bcryptjs.default.genSalt(SALT_WORK_FACTOR, function (error, salt) {
      if (error) return reject(error);

      _bcryptjs.default.hash(password, salt, function (error, hash) {
        if (error) return reject(error);
        user.password = hash;
        resolve(hash);
      });
    });
  });
}

function compare(user, password) {
  var userPassword = user.password;
  if (!userPassword) throw new Error('No password provided');
  return new Promise(function (resolve, reject) {
    _bcryptjs.default.compare(password, userPassword, function (error, result) {
      if (error) return reject(error);
      resolve(result);
    });
  });
}

function reset(user) {
  return new Promise(function (resolve, reject) {
    _crypto.default.randomBytes(20, function (error, buffer) {
      if (error) return reject(error);
      var token = buffer.toString('hex');
      user.resetPasswordToken = token;
      user.resetPasswordExpires = Date.now() + 3600000;
      resolve(token);
    });
  });
}

function update(_x, _x2) {
  return _update.apply(this, arguments);
}

function _update() {
  _update = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee(user, password) {
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            user.password = password;
            user.resetPasswordToken = undefined;
            user.resetPasswordExpires = undefined;
            _context.next = 5;
            return hash(user);

          case 5:
            return _context.abrupt("return", user);

          case 6:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));
  return _update.apply(this, arguments);
}

var _default = {
  hash: hash,
  compare: compare,
  reset: reset,
  update: update
};
exports.default = _default;